summaryrefslogtreecommitdiffstats
path: root/win/qeventloopex.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
commit10308be19ef7fa44699562cc75946e7ea1fdf6b9 (patch)
tree4bc444c00a79e88105f2cfce5b6209994c413ca0 /win/qeventloopex.cpp
parent307136d8eef0ba133b78ceee8e901138d4c996a1 (diff)
downloadtdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.tar.gz
tdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.zip
Revert automated changes
Sorry guys, they are just not ready for prime time Work will continue as always git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1212479 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'win/qeventloopex.cpp')
-rw-r--r--win/qeventloopex.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/win/qeventloopex.cpp b/win/qeventloopex.cpp
index 9db6bd133..da5eba60c 100644
--- a/win/qeventloopex.cpp
+++ b/win/qeventloopex.cpp
@@ -263,7 +263,7 @@ void QEventLoopEx::unregisterSocketNotifier( TQSocketNotifier *notifier )
SetEvent(d->m_evPendingListEmpty);
list->remove(); // remove notifier found above
- if ( d->sn_highest == sockfd ) {// tqfind highest fd
+ if ( d->sn_highest == sockfd ) {// find highest fd
d->sn_highest = -1;
for ( int i=0; i<3; i++ ) {
if ( d->sn_vec[i].list && ! d->sn_vec[i].list->isEmpty() )
@@ -433,7 +433,7 @@ void QEventLoopEx::run()
if (WSAGetLastError() == WSAENOTSOCK) {
// it seems a socket notifier has a bad fd... tqfind out
// which one it is and disable it
fd_set fdset;
struct timeval zerotm;
@@ -433,7 +433,7 @@ void QEventLoopEx::run()
if (WSAGetLastError() == WSAENOTSOCK) {
- // it seems a socket notifier has a bad fd... tqfind out
+ // it seems a socket notifier has a bad fd... find out
// which one it is and disable it
fd_set fdset;